@@ -16,6 +16,9 @@
 #You should have received a copy of the GNU General Public License along 
 #with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+import glob
+import imp
+import os
 import sys
 from quickly import templatetools, commands
 
@@ -26,15 +29,32 @@ gettext.textdomain('quickly')
 
 argv = sys.argv
 
-from store import *
-import store
+ADDABLE = {}
+def get_addable_from_path(_path):
+    '''parse addable files'''
+    _path = os.path.expanduser(_path)
+    globs = glob.glob('%s/*.py' % _path)
+    # get only files
+    addable_files = [y for y in globs if os.path.isfile(y)]
+    # exclude __init__.py
+    addable_files = [y for y in addable_files if os.path.basename(y)[0] != '_']
+    for _file in addable_files:
+        _basename = os.path.splitext(os.path.basename(_file))[0]
+        py_mod = imp.load_source(_basename,_file)
+        ADDABLE.update(((_basename, py_mod),))
 
-addable = [x for x in dir(store) if x[0] != '_']
+def get_addable():
+    parent_path = os.path.dirname(__file__)
+    template_path = templatetools.get_template_path_from_project()
+    get_addable_from_path(os.path.join(parent_path, 'store'))
+    get_addable_from_path(os.path.join(template_path, 'store'))
+
+get_addable()
 
 options = {}
-for module in addable:
+for item in ADDABLE.items():
     try:
-        options[module] = getattr(store, module).option
+        options[item[0]] = item[1].option
     except AttributeError:
         # ignore files in store that have no option for us
         pass
@@ -44,9 +64,10 @@ def usage():
 
 def help():
     help_list = [_('Add something to your project\n')]
-    for module in addable:
+    # TODO sort keys
+    for module in ADDABLE.values():
         try:
-            help_list.append(getattr(store, module).help_text)
+            help_list.append(module.help_text)
         except AttributeError:
             # ignore files in store that have no help for us
             pass
@@ -68,8 +89,8 @@ if len(sys.argv) < 2:
     cmd = commands.get_command('add', 'ubuntu-application')
     templatetools.usage_error(_("Cannot add, no plugin name provided."), cmd=cmd, template='ubuntu-application')
 
-if argv[1] in addable:
-    getattr(store, argv[1]).add(options)
+if argv[1] in ADDABLE.keys():
+    ADDABLE[argv[1]].add(options)
 else:
     cmd = commands.get_command('add', 'ubuntu-application')
     templatetools.usage_error(_('Cannot add, did not recognize plugin name: %s' % argv[1]), cmd=cmd, template='ubuntu-application')
