@@ -118,6 +118,7 @@ def _filter_out(line, output_domain, err_output, warn_output):
             if not(re.match('  .*\.pot', line)
                    or re.match('  .*\.in', line)
                    or re.match(' dpkg-genchanges  >.*', line)
+                   or re.match('.*encoding declaration in Unicode string.*', line)
                    # python-mkdebian warns on help files
                    or re.match('  help/.*/.*', line)
                    # FIXME: this warning is temporary: should be withed in p-d-e
@@ -158,62 +159,14 @@ def _exec_and_log_errors(command, ask_on_warn_or_error=False):
         return(_continue_if_errors(err_output, warn_output, proc.returncode,
                                      ask_on_warn_or_error))
 
-def update_metadata():
-    # See https://wiki.ubuntu.com/PostReleaseApps/Metadata for details
-
-    metadata = []
-    project_name = configurationhandler.project_config['project']
-
-    # Grab name and category from desktop file
-    with open('%s.desktop.in' % project_name, 'r') as f:
-        desktop = f.read()
-
-        match = re.search('\n_?Name=(.*)\n', desktop)
-        if match is not None:
-            metadata.append('XB-AppName: %s' % match.group(1))
-
-        match = re.search('\nCategories=(.*)\n', desktop)
-        if match is not None:
-            metadata.append('XB-Category: %s' % match.group(1))
-
-    # Grab distribution for screenshot URLs from debian/changelog
-    changelog = subprocess.Popen(['dpkg-parsechangelog'], stdout=subprocess.PIPE).communicate()[0]
-    match = re.search('\nDistribution: (.*)\n', changelog)
-    if match is not None:
-        distribution = match.group(1)
-        first_letter = project_name[0]
-        urlbase = 'https://software-center.ubuntu.com/screenshots/%s' % first_letter
-        metadata.append('XB-Screenshot-Url: %s/%s-%s.png' % (urlbase, project_name, distribution))
-        metadata.append('XB-Thumbnail-Url: %s/%s-%s.thumb.png' % (urlbase, project_name, distribution))
-
-    # Now ship the icon as part of the debian packaging
-    icon_name = 'data/media/%s.svg' % project_name
-    if not os.path.exists(icon_name):
-        # Support pre-11.03.1 icon names
-        icon_name = 'data/media/logo.svg'
-        if not os.path.exists(icon_name):
-            icon_name = None
-    if icon_name:
-        contents = ''
-        with open('debian/rules', 'r') as f:
-            contents = f.read()
-        if contents and re.search('dpkg-distaddfile %s.svg' % project_name, contents) is None:
-            contents += """
-override_dh_install::
-	dh_install
-	cp %(icon_name)s ../%(project_name)s.svg
-	dpkg-distaddfile %(project_name)s.svg raw-meta-data -""" % {
-                'project_name': project_name, 'icon_name': icon_name}
-            templatetools.set_file_contents('debian/rules', contents)
-
-            metadata.append('XB-Icon: %s.svg' % project_name)
-
-    # Prepend the start-match line, because update_file_content replaces it
-    metadata.insert(0, 'XB-Python-Version: ${python:Versions}')
-    templatetools.update_file_content('debian/control',
-                                      'XB-Python-Version: ${python:Versions}',
-                                      'Depends: ${misc:Depends},',
-                                      '\n'.join(metadata) + '\n')
+def update_rules():
+    # Also update debian/control to add a new Build-Depends needed for
+    # glib-compile-schemas
+    templatetools.update_file_content(
+        'debian/control',
+        "Build-Depends: debhelper (>= 8),",
+        " python (>= 2.6.6-3~),",
+        "Build-Depends: debhelper (>= 8), libglib2.0-bin,")
 
 def get_python_mkdebian_version():
     proc = subprocess.Popen(["python-mkdebian", "--version"], stdout=subprocess.PIPE)
@@ -275,7 +228,7 @@ def updatepackaging(changelog=None, no_changelog=False, installopt=False):
         return(return_code)
 
     if installopt:
-        update_metadata()
+        update_rules()
 
     print _("Ubuntu packaging created in debian/")
 
