@@ -11,9 +11,7 @@
 
 from gi.repository import Gio # pylint: disable=E0611
 
-import gettext
-from gettext import gettext as _
-gettext.textdomain('project_name')
+from locale import gettext as _
 
 import logging
 logger = logging.getLogger('python_name')
