@@ -5,9 +5,7 @@
 
 import optparse
 
-import gettext
-from gettext import gettext as _
-gettext.textdomain('project_name')
+from locale import gettext as _
 
 from gi.repository import Gtk # pylint: disable=E0611
 
