@@ -26,18 +26,14 @@ gettext.textdomain('quickly')
 
 from quickly import templatetools
 
+def usage():
+    templatetools.print_usage(_('quickly save [comments]'))
 def help():
-    print _("""Usage:
-$quickly save notes about changes
-where "notes about changes" is optional text describing what changes
-were made since the last save.
-
-This command commits all changes since the last save to bzr. Note that 
+    print _("""This command commits all changes since the last save to bzr. Note that 
 it does not push changes to any back up location. If you need revert
 or otherwise use the revision control, use bzr directly:
-$bzr help
-""")
-templatetools.handle_additional_parameters(sys.argv, help)
+$ bzr help""")
+templatetools.handle_additional_parameters(sys.argv, help, usage=usage)
 
 #set either a default message or the specified message
 commit_msg = " ".join(sys.argv[1:])
