@@ -21,18 +21,9 @@ quickly package | sed 's/^\.\+//'
 # Ubuntu package has been successfully created in ../test-project_0.1_all.deb
 
 bzr status
-# modified:
-#   test-project.desktop.in
 # unknown:
 #   po/
 
-bzr diff --diff-options="-e"
-# === modified file 'test-project.desktop.in'
-# 6c
-# Icon=/usr/share/test-project/media/test-project.svg
-# .
-# 
-
 ls debian
 # changelog
 # compat
@@ -49,7 +40,7 @@ grep UNKNOWN debian/*
 # debian/control:Maintainer: UNKNOWN <UNKNOWN>
 # debian/control:Description: UNKNOWN
 # debian/control: UNKNOWN
-# debian/copyright:Maintainer: UNKNOWN <UNKNOWN>
+# debian/copyright:Upstream-Contact: UNKNOWN <UNKNOWN>
 # debian/copyright:Source: UNKNOWN
 # debian/copyright:License: UNKNOWN
 
@@ -81,8 +72,8 @@ cd unpacked
 
 ar p ../../test-project_0.1_all.deb data.tar.gz | tar xz
 
-grep -Rh "__version__ = " usr/share/pyshared
+grep -Rh "__version__ = " usr/lib/python*
 # __version__ = '0.1'
 
-grep -Rh "__test_project_data_directory__ = " usr/share/pyshared
+grep -Rh "__test_project_data_directory__ = " usr/lib/python*
 # __test_project_data_directory__ = '/usr/share/test-project/'
