@@ -1,10 +1,7 @@
 #!/usr/bin/python
 # -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
 
-import nautilus
-import pygtk
-import gtk
-import vte
+from gi.repository import GLib, GdkPixbuf, Gtk, Nautilus, Vte # pylint: disable=E0611
 
 try:
     from quickly import api as quicklyapi
@@ -16,7 +13,7 @@ except:
 command_order = ('create', 'edit', 'design', 'save', 'package', 'share', 'release', 'tutorial')
 command_without_output = ('edit', 'design', 'save', 'tutorial')
 
-class DevBar(nautilus.LocationWidgetProvider):
+class DevBar(Nautilus.LocationWidgetProvider):
     pass
     def __init__(self):
         self.bars = {}
@@ -73,12 +70,12 @@ class DevBar(nautilus.LocationWidgetProvider):
         return bar
 
 
-class UbuntuDevBar(gtk.HBox):
+class UbuntuDevBar(Gtk.HBox):
     '''Container to all buttons in nautilus.'''
 
     def __init__(self, *args, **kwargs):
         '''create a Ubuntu Dev Bar'''
-        super(UbuntuDevBar, self).__init__(*args, **kwargs)
+        Gtk.HBox.__init__(*args, **kwargs)
         self._logo = None
         self._image = None
         self._subtitle = None
@@ -87,16 +84,16 @@ class UbuntuDevBar(gtk.HBox):
 
     def add_image(self, image_name, subtitle=None):
         """Add an image to the bar and a subtitle below if one."""
-        self._logo = gtk.VBox(homogeneous=False, spacing=0)
-        self._image = gtk.Image()
+        self._logo = Gtk.VBox(homogeneous=False, spacing=0)
+        self._image = Gtk.Image()
         self._logo.pack_start(self._image, expand=True, fill=True, padding=0)
-        pixbuf = gtk.gdk.pixbuf_new_from_file(image_name)
+        pixbuf = GdkPixbuf.Pixbuf.new_from_file(image_name)
         if pixbuf:
-            scaled_pixbuf = pixbuf.scale_simple(48, 48, gtk.gdk.INTERP_BILINEAR)
+            scaled_pixbuf = pixbuf.scale_simple(48, 48, GdkPixbuf.InterpType.BILINEAR)
             self._image.set_from_pixbuf(scaled_pixbuf)
             self._image.show()
         if subtitle:
-            self._subtitle = gtk.Label(subtitle)
+            self._subtitle = Gtk.Label(subtitle)
             self._logo.pack_start(self._subtitle, expand=True, fill=True, padding=0)
             self._subtitle.show()
         self.pack_start(self._logo, expand=False, fill=False, padding=0)
@@ -104,17 +101,17 @@ class UbuntuDevBar(gtk.HBox):
 
     def add_button(self, signal, label, command_line, path, icon=None):
         """Adds a new new button to the bar widget."""
-        button = gtk.Button()
+        button = Gtk.Button()
         button.connect("clicked", signal, command_line, path)
         button.set_label(label)
         if icon:
-            image = gtk.Image()
+            image = Gtk.Image()
             image.set_from_file(icon)
             settings = button.get_settings()
             settings.set_property("gtk-button-images", True)
             button.set_image(image)
         button.show()
-        vbox = gtk.VBox(homogeneous=False, spacing=0)
+        vbox = Gtk.VBox(homogeneous=False, spacing=0)
         vbox.pack_start(button, expand=True, fill=False, padding=0)
         vbox.show()
         self._buttons.append(button)
@@ -123,21 +120,21 @@ class UbuntuDevBar(gtk.HBox):
     def add_button_with_selection(self, signal, label, selection, command_line,
                                   path, icon=None):
         """Adds a new button with a multiple selection widget"""
-        combobox = gtk.combo_box_new_text()
+        combobox = Gtk.ComboBoxText()
         for item in selection:
             combobox.append_text(item)
         combobox.show()
-        button = gtk.Button()
+        button = Gtk.Button()
         button.set_label(label)
         button.connect("clicked", signal, command_line, path, combobox)
         if icon:
-            image = gtk.Image()
+            image = Gtk.Image()
             image.set_from_file(icon)
             settings = button.get_settings()
             settings.set_property("gtk-button-images", True)
             button.set_image(image)
         button.show()
-        vbox = gtk.VBox(homogeneous=False, spacing=0)
+        vbox = Gtk.VBox(homogeneous=False, spacing=0)
         vbox.pack_start(combobox, expand=True, fill=False, padding=0)
         vbox.pack_start(button, expand=True, fill=False, padding=0)
         self._buttons_with_selection.append((combobox,button))
@@ -158,13 +155,14 @@ class UbuntuDevBar(gtk.HBox):
         except IndexError:
             pass
         command = self.add_additional_actions(command)
-        v = vte.Terminal()
-        v.fork_command(command[0], argv=command, directory=argscommand[1])
-        window = gtk.Window()
+        v = Vte.Terminal()
+        v.fork_command_full(Vte.PtyFlags.DEFAULT, argscommand[1], command,
+                            None, GLib.SpawnFlags.SEARCH_PATH, None, None)
+        window = Gtk.Window()
         window.add(v)
         if command[1] not in command_without_output:
             window.show_all()
-        gtk.main()
+        Gtk.main()
 
     def add_additional_actions(self, command):
         """Some commands needs additional args, filter them here"""
@@ -172,7 +170,7 @@ class UbuntuDevBar(gtk.HBox):
         # TODO: Add missing prompts module
         #if command[1] == "create":
         #    response, val = prompts.string("Project Name","Please enter a project name")
-        #    if response == gtk.RESPONSE_OK:
+        #    if response == Gtk.ResponseType.OK:
         #        command.append(val)
 
         return command
